[evolution-data-server/openismus-work-master: 96/134] Changes for Review: EBookBackendSqliteDB fixed spelling mistakes



commit 02f78705f150f8392e5ba48ee3cdfa8713b4138a
Author: Tristan Van Berkom <tristanvb openismus com>
Date:   Sat Oct 5 23:45:03 2013 +0200

    Changes for Review: EBookBackendSqliteDB fixed spelling mistakes

 .../libedata-book/e-book-backend-sqlitedb.c        |   23 +++++++++----------
 .../libedata-book/e-book-backend-sqlitedb.h        |    6 ++--
 2 files changed, 14 insertions(+), 15 deletions(-)
---
diff --git a/addressbook/libedata-book/e-book-backend-sqlitedb.h 
b/addressbook/libedata-book/e-book-backend-sqlitedb.h
index 9139624..d6cb580 100644
--- a/addressbook/libedata-book/e-book-backend-sqlitedb.h
+++ b/addressbook/libedata-book/e-book-backend-sqlitedb.h
@@ -125,7 +125,7 @@ typedef struct {
 typedef struct _EbSdbCursor EbSdbCursor;
 
 /**
- * EbSdbCurorOrigin:
+ * EbSdbCursorOrigin:
  * @EBSDB_CURSOR_ORIGIN_CURRENT:  The current cursor position
  * @EBSDB_CURSOR_ORIGIN_PREVIOUS: The previously recorded cursor position, this can be used to repeat the 
previous query
  * @EBSDB_CURSOR_ORIGIN_RESET:    The beginning of the cursor results (or end of the results, if navigating 
in reverse).
@@ -141,7 +141,7 @@ typedef enum {
        EBSDB_CURSOR_ORIGIN_CURRENT,
        EBSDB_CURSOR_ORIGIN_PREVIOUS,
        EBSDB_CURSOR_ORIGIN_RESET
-} EbSdbCurorOrigin;
+} EbSdbCursorOrigin;
 
 GType          e_book_backend_sqlitedb_get_type
                                                (void) G_GNUC_CONST;
@@ -335,7 +335,7 @@ void            e_book_backend_sqlitedb_cursor_free
 gboolean        e_book_backend_sqlitedb_cursor_move_by
                                                 (EBookBackendSqliteDB *ebsdb,
                                                 EbSdbCursor          *cursor,
-                                                EbSdbCurorOrigin      origin,
+                                                EbSdbCursorOrigin     origin,
                                                 gint                  count,
                                                 GSList              **results,
                                                 GError              **error);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/addressbook/libedata-book/e-book-backend-sqlitedb.c 
b/addressbook/libedata-book/e-book-backend-sqlitedb.c
index a1951ab..1d4675b 100644
--- a/addressbook/libedata-book/e-book-backend-sqlitedb.c
+++ b/addressbook/libedata-book/e-book-backend-sqlitedb.c
@@ -4052,7 +4052,7 @@ book_backend_sqlitedb_search_query (EBookBackendSqliteDB *ebsdb,
 
                        success = book_backend_sql_exec (
                                ebsdb->priv->db, stmt,
-                               addto_vcard_list_cb , &vcard_data, error);
+                               addto_vcard_list_cb, &vcard_data, error);
 
                        sqlite3_free (stmt);
                } else {
@@ -5688,7 +5688,7 @@ cursor_count_position_locked (EBookBackendSqliteDB *ebsdb,
 
        /* Add the cursor constraints (if any) */
        if (cursor->state[STATE_CURRENT].values[0] != NULL) {
-               gchar  *constraints = NULL;
+               gchar *constraints = NULL;
 
                if (!cursor->query)
                        g_string_append (query, " WHERE ");
@@ -5725,7 +5725,7 @@ cursor_count_position_locked (EBookBackendSqliteDB *ebsdb,
  * @sort_fields: (array length=n_sort_fields): An array of #EContactFields as sort keys in order of priority
  * @sort_types: (array length=n_sort_fields): An array of #EBookCursorSortTypes, one for each field in 
@sort_fields
  * @n_sort_fields: The number of fields to sort results by.
- * @error: A return location to story any error that might be reported.
+ * @error: A return location to store any error that might be reported.
  *
  * Creates a new #EbSdbCursor.
  *
@@ -5850,11 +5850,11 @@ collect_results_for_cursor_cb (gpointer ref,
  * e_book_backend_sqlitedb_cursor_move_by:
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to use
  * @origin: The #EbSdbCurorOrigin for this move
  * @count: A positive or negative amount of contacts to try and fetch
  * @results: (out) (allow-none) (element-type EbSdbSearchData) (transfer full):
  *   A return location to store the results, or %NULL to move the cursor without retrieving any results.
- * @error: A return location to story any error that might be reported.
+ * @error: A return location to store any error that might be reported.
  *
  * Moves @cursor through the @ebsdb by @count and fetch a maximum of @count contacts.
  *
@@ -5873,15 +5873,14 @@ collect_results_for_cursor_cb (gpointer ref,
  * the result list will be stored to @results and should be freed with g_slist_free()
  * and all elements freed with e_book_backend_sqlitedb_search_data_free().
  *
- * Returns: %TRUE on Success, otherwise %FALSE is returned if any error occurred
- * and @error is set to reflect the error which occurred.
+ * Returns: %TRUE on success, otherwise %FALSE is returned and @error is set.
  *
  * Since: 3.10
  */
 gboolean
 e_book_backend_sqlitedb_cursor_move_by (EBookBackendSqliteDB *ebsdb,
                                        EbSdbCursor          *cursor,
-                                       EbSdbCurorOrigin      origin,
+                                       EbSdbCursorOrigin     origin,
                                        gint                  count,
                                        GSList              **results,
                                        GError              **error)
@@ -5932,7 +5931,7 @@ e_book_backend_sqlitedb_cursor_move_by (EBookBackendSqliteDB *ebsdb,
 
        /* Add the cursor constraints (if any) */
        if (cursor->state[STATE_CURRENT].values[0] != NULL) {
-               gchar  *constraints = NULL;
+               gchar *constraints = NULL;
 
                if (!cursor->query)
                        g_string_append (query, " WHERE ");
@@ -6018,7 +6017,7 @@ e_book_backend_sqlitedb_cursor_move_by (EBookBackendSqliteDB *ebsdb,
  * will return results starting with the letter 'E' (or results starting
  * with the last result in 'D', if moving in a negative direction).
  *
- * The passed index must be a valid index in the active locale, knowlege
+ * The passed index must be a valid index in the active locale, knowledge
  * on the currently active alphabet index must be obtained using #ECollator
  * APIs.
  *
@@ -6056,7 +6055,7 @@ e_book_backend_sqlitedb_cursor_set_target_alphabetic_index (EBookBackendSqliteDB
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor
  * @sexp: The new query expression for @cursor
- * @error: A return location to story any error that might be reported.
+ * @error: A return location to store any error that might be reported.
  *
  * Modifies the current query expression for @cursor. This will not
  * modify @cursor's state, but will change the outcome of any further
@@ -6100,7 +6099,7 @@ e_book_backend_sqlitedb_cursor_set_sexp (EBookBackendSqliteDB *ebsdb,
  * @cursor: The #EbSdbCursor
  * @total: (out) (allow-none): A return location to store the total result set for this cursor
  * @position: (out) (allow-none): A return location to store the total results before the cursor value
- * @error: (allow-none): A return location to story any error that might be reported.
+ * @error: (allow-none): A return location to store any error that might be reported.
  *
  * Calculates the @total amount of results for the @cursor's query expression,
  * as well as the current @position of @cursor in the results. @position is
@@ -5850,11 +5850,11 @@ collect_results_for_cursor_cb (gpointer ref,
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to use
- * @origin: The #EbSdbCurorOrigin for this move
+ * @origin: The #EbSdbCursorOrigin for this move
  * @count: A positive or negative amount of contacts to try and fetch
  * @results: (out) (allow-none) (element-type EbSdbSearchData) (transfer full):